@@ -540,6 +540,33 @@ for item in json_array_unpack(raw_data) union ({insert_str}) {given_resolver.to_
             new_node._deleted = True
             models_by_id[new_node.id].hydrate(new_node=new_node)
 
+    @classmethod
+    async def delete_from_filtered_resolver(
+        cls,
+        filtered_resolver: "ResolverType",
+        batch: Batch = None,
+        given_client: edgedb.AsyncIOClient = None,
+    ) -> T.Optional[T.List[ThisNodeType]]:
+        if batch:
+            batch.add(
+                line=filtered_resolver.inner_delete_str(),
+                variables=filtered_resolver._get_nested_query_variables(),
+            )
+            return
+        with safe_span(op=f"edgedb.delete_from_filtered_resolver.{cls._model_name}"):
+            raw_d = await execute_query(
+                client=given_client or cls.db_client,
+                query_str=filtered_resolver.full_delete_str(),
+                variables=filtered_resolver._get_nested_query_variables(),
+                only_one=False,
+            )
+            debug(raw_d)
+        with safe_span(op=f"parse.{cls._model_name}", description=f"{len(raw_d)=}"):
+            nodes = [filtered_resolver.parse_nested_obj(d) for d in raw_d]
+        for node in nodes:
+            node._deleted = True
+        return nodes
+
     @classmethod
     def build_update_d_from_patch(cls, patch: PatchType) -> dict:
         update_d = {}
